@@ -25,28 +25,26 @@ import (
 	"errors"
 	"fmt"
 	"log"
-	"os"
 	"regexp"
 	"strconv"
 
-	"github.com/b4nst/turbogit/internal/format"
+	"github.com/b4nst/turbogit/pkg/format"
+	tugit "github.com/b4nst/turbogit/pkg/git"
 	"github.com/blang/semver/v4"
-	git "github.com/libgit2/git2go/v30"
+	git "github.com/libgit2/git2go/v31"
 	"github.com/spf13/cobra"
 )
 
-const (
-	TAG_PREFIX = "v"
-)
-
 func init() {
 	RootCmd.AddCommand(tagCmd)
 
 	tagCmd.Flags().BoolP("dry-run", "d", false, "Do not tag.")
+	tagCmd.Flags().StringP("prefix", "p", "v", "Tag prefix.")
 }
 
 type TagCmdOption struct {
 	DryRun bool
+	Prefix string
 	Repo   *git.Repository
 }
 
@@ -83,42 +81,64 @@ func parseTagCmd(cmd *cobra.Command, args []string) (*TagCmdOption, error) {
 		return nil, err
 	}
 
+	// --prefix
+	fPrefix, err := cmd.Flags().GetString("prefix")
+	if err != nil {
+		return nil, err
+	}
+
 	// Find repo
-	wd, err := os.Getwd()
-	if err != nil {
-		return nil, err
-	}
-	rpath, err := git.Discover(wd, false, nil)
-	if err != nil {
-		return nil, err
-	}
-	repo, err := git.OpenRepository(rpath)
+	repo, err := tugit.Getrepo()
 	if err != nil {
 		return nil, err
 	}
 
 	return &TagCmdOption{
 		DryRun: fDryRun,
+		Prefix: fPrefix,
 		Repo:   repo,
 	}, nil
 }
 
+func commitWalker(bump *format.Bump, curr *semver.Version, prefix string) (func(*git.Commit) bool, error) {
+	dfo, err := git.DefaultDescribeFormatOptions()
+	if err != nil {
+		return nil, err
+	}
+	dco := &git.DescribeOptions{
+		MaxCandidatesTags:     1,
+		Strategy:              git.DescribeTags,
+		Pattern:               fmt.Sprintf("%s*", prefix),
+		OnlyFollowFirstParent: true,
+	}
+
+	return func(c *git.Commit) bool {
+		dr, err := c.Describe(dco)
+		if err != nil {
+			// No next tag matching
+			*bump = format.NextBump(c.Message(), *bump)
+			return true
+		}
+		d, err := dr.Format(&dfo)
+		if err != nil {
+			panic(err)
+		}
+		v, offset, err := parseDescription(d)
+		*curr = *v
+		if err != nil {
+			panic(err)
+		}
+		if offset <= 1 {
+			return false
+		}
+		*bump = format.NextBump(c.Message(), *bump)
+		return true
+	}, nil
+}
+
 func runTag(tco *TagCmdOption) error {
 	r := tco.Repo
 
-	bump := format.BUMP_NONE
-	var curr *semver.Version
-	dfo, err := git.DefaultDescribeFormatOptions()
-	if err != nil {
-		return err
-	}
-	dco := &git.DescribeOptions{
-		MaxCandidatesTags:     1,
-		Strategy:              git.DescribeTags,
-		Pattern:               fmt.Sprintf("%s*", TAG_PREFIX),
-		OnlyFollowFirstParent: true,
-	}
-
 	walk, err := r.Walk()
 	if err != nil {
 		return err
@@ -127,29 +147,12 @@ func runTag(tco *TagCmdOption) error {
 		return err
 	}
 
-	walker := func(c *git.Commit) bool {
-		dr, err := c.Describe(dco)
-		if err != nil {
-			// No next tag matching
-			bump = format.NextBump(c.Message(), bump)
-			return true
-		}
-		d, err := dr.Format(&dfo)
-		if err != nil {
-			panic(err)
-		}
-		var offset int
-		curr, offset, err = parseDescription(d)
-		if err != nil {
-			panic(err)
-		}
-		if offset <= 1 {
-			return false
-		}
-		bump = format.NextBump(c.Message(), bump)
-		return true
+	bump := format.BUMP_NONE
+	curr := semver.Version{}
+	walker, err := commitWalker(&bump, &curr, tco.Prefix)
+	if err != nil {
+		return err
 	}
-
 	if err := walk.Iterate(walker); err != nil {
 		return err
 	}
@@ -158,35 +161,35 @@ func runTag(tco *TagCmdOption) error {
 		fmt.Println("Nothing to do")
 		return nil
 	}
-
-	if curr == nil {
-		curr = &semver.Version{}
-	}
-	if err := bumpVersion(curr, bump); err != nil {
+	// Bump tag
+	if err := bumpVersion(&curr, bump); err != nil {
 		return err
 	}
 
-	tagname := fmt.Sprintf("refs/tags/%s%s", TAG_PREFIX, curr)
-	if tco.DryRun {
-		fmt.Println(tagname, "will be created")
-		return nil
-	}
+	tagname := fmt.Sprintf("refs/tags/%s%s", tco.Prefix, curr)
+	return tagHead(r, tagname, tco.DryRun)
+}
 
+func tagHead(r *git.Repository, tagname string, dry bool) error {
 	head, err := r.Head()
 	if err != nil {
 		return err
 	}
-	tag, err := r.References.Create(tagname, head.Target(), false, "")
-	if err != nil {
-		return err
+	if dry {
+		fmt.Println(tagname, "would be created on", head.Target())
+	} else {
+		tag, err := r.References.Create(tagname, head.Target(), false, "")
+		if err != nil {
+			return err
+		}
+		fmt.Println(tag.Target(), "-->", tagname)
 	}
-	fmt.Println(tag.Target(), "-->", tagname)
 	return nil
 }
 
 func bumpVersion(curr *semver.Version, bump format.Bump) error {
 	if curr == nil {
-		return errors.New("Received nil pointer")
+		return errors.New("Received nil pointer for version")
 	}
 	switch bump {
 	case format.BUMP_MAJOR:
